@@ -10,13 +10,12 @@ from datetime import datetime
 from typing import List, Union, Optional, Dict, ClassVar, cast
 
 import jsonschema.validators
-from pyrsistent import pmap, pvector
 
 import mmif
 from mmif import ThingTypesBase
 from mmif.vocabulary import AnnotationTypes, DocumentTypes
 from .annotation import Annotation, Document
-from .model import MmifObject, DataList, FreezableDataList
+from .model import MmifObject, DataList
 from .view import View
 
 __all__ = ['Mmif']
@@ -31,24 +30,22 @@ class Mmif(MmifObject):
     """
 
     view_prefix: ClassVar[str] = 'v_'
+    id_delimiter: ClassVar[str] = ':'
 
-    def __init__(self, mmif_obj: Union[bytes, str, dict] = None, *, validate: bool = True, frozen: bool = True) -> None:
+    def __init__(self, mmif_obj: Optional[Union[bytes, str, dict]] = None, *, validate: bool = True) -> None:
         self.metadata: MmifMetadata = MmifMetadata()
         self.documents: DocumentsList = DocumentsList()
         self.views: ViewsList = ViewsList()
         if validate:
             self.validate(mmif_obj)
         self.disallow_additional_properties()
-        self._attribute_classes = pmap({
+        self._attribute_classes = {
             'metadata': MmifMetadata,
             'documents': DocumentsList,
             'views': ViewsList
-        })
-        self._required_attributes = pvector(["metadata", "documents", "views"])
+        }
+        self._required_attributes = ["metadata", "documents", "views"]
         super().__init__(mmif_obj)
-        if frozen:
-            self.freeze_documents()
-            self.freeze_views()
 
     @staticmethod
     def validate(json_str: Union[bytes, str, dict]) -> None:
@@ -120,40 +117,9 @@ class Mmif(MmifObject):
                           an existing view with the same ID
         :return: None
         """
-        if not self.documents.is_frozen():
-            self.documents.append(document, overwrite)
-        else:
-            raise TypeError("MMIF object is frozen")
+        self.documents.append(document, overwrite)
 
-    def freeze(self):
-        """
-        Deeply freezes all elements. Returns True only when everything if frozen.
-        """
-        doc_frozen = self.freeze_documents()
-        view_frozen = self.freeze_views()
-        return view_frozen and doc_frozen
-        
-    def freeze_documents(self) -> bool:
-        """
-        Deeply freezes the list of documents. Returns the result of
-        the deep_freeze() call, signifying whether everything
-        was fully frozen or not.
-        """
-        return self.documents.deep_freeze()
-
-    def freeze_views(self) -> bool:
-        """
-        Deeply freezes all of the existing views without freezing
-        the list of views itself. Returns the conjunct of the returns
-        of all of the deep_freeze() calls, signifying whether everything
-        was fully frozen or not.
-        """
-        fully_frozen = True
-        for view in self.views:
-            fully_frozen &= view.deep_freeze()
-        return fully_frozen
-
-    def get_documents_in_view(self, vid: str = None) -> List[Document]:
+    def get_documents_in_view(self, vid: Optional[str] = None) -> List[Document]:
         """
         Method to get all documents object queries by a view id.
 
@@ -209,7 +175,7 @@ class Mmif(MmifObject):
         docs.extend([document for document in self.documents if document.properties[prop_key] == prop_value])
         return docs
 
-    def get_documents_locations(self, m_type: Union[DocumentTypes, str], path_only=False) -> List[str]:
+    def get_documents_locations(self, m_type: Union[DocumentTypes, str], path_only=False) -> List[Union[str, None]]:
         """
         This method returns the file paths of documents of given type.
         Only top-level documents have locations, so we only check them.
@@ -217,7 +183,7 @@ class Mmif(MmifObject):
         :param m_type: the type to search for
         :return: a list of the values of the location fields in the corresponding documents
         """
-        docs = [document for document in self.documents if document.is_type(m_type) and len(document.location) > 0]
+        docs = [document for document in self.documents if document.is_type(m_type) and document.location is not None]
         if path_only:
             return [doc.location_path() for doc in docs]
         else:
@@ -242,8 +208,8 @@ class Mmif(MmifObject):
         :return: a reference to the corresponding document, if it exists
         :raises Exception: if there is no corresponding document
         """
-        if ":" in doc_id:
-            vid, did = doc_id.split(":")
+        if Mmif.id_delimiter in doc_id:
+            vid, did = doc_id.split(Mmif.id_delimiter)
             view = self[vid]
             if isinstance(view, View):
                 return view.get_document_by_id(did) 
@@ -290,8 +256,8 @@ class Mmif(MmifObject):
                     aligned_types = set()
                     for ann_id in [alignment.properties['target'], alignment.properties['source']]:
                         ann_id = cast(str, ann_id)
-                        if ':' in ann_id:
-                            view_id, ann_id = ann_id.split(':')
+                        if Mmif.id_delimiter in ann_id:
+                            view_id, ann_id = ann_id.split(Mmif.id_delimiter)
                             aligned_type = cast(Annotation, self[view_id][ann_id]).at_type
                         else:
                             aligned_type = cast(Annotation, alignment_view[ann_id]).at_type
@@ -317,8 +283,8 @@ class Mmif(MmifObject):
                 views.append(view)
             except StopIteration:
                 # search failed by the full doc_id string, now try trimming the view_id from the string and re-do the search
-                if ':' in doc_id:
-                    vid, did = doc_id.split(':')
+                if Mmif.id_delimiter in doc_id:
+                    vid, did = doc_id.split(Mmif.id_delimiter)
                     if view.id == vid:
                         annotations = view.get_annotations(document=did)
                         try:
@@ -380,7 +346,7 @@ class Mmif(MmifObject):
         """
         if item in self._named_attributes():
             return self.__dict__[item]
-        split_attempt = item.split(':')
+        split_attempt = item.split(Mmif.id_delimiter)
 
         document_result = self.documents.get(split_attempt[0])
         view_result = self.views.get(split_attempt[0])
@@ -407,21 +373,21 @@ class MmifMetadata(MmifObject):
     :param metadata_obj: the JSON data
     """
 
-    def __init__(self, metadata_obj: Union[bytes, str, dict] = None) -> None:
+    def __init__(self, metadata_obj: Optional[Union[bytes, str, dict]] = None) -> None:
         # TODO (krim @ 10/7/20): there could be a better name and a better way to give a value to this
         self.mmif: str = f"http://mmif.clams.ai/{mmif.__specver__}"
-        self._required_attributes = pvector(["mmif"])
+        self._required_attributes = ["mmif"]
         super().__init__(metadata_obj)
 
 
-class DocumentsList(FreezableDataList[Document]):
+class DocumentsList(DataList[Document]):
     """
     DocumentsList object that implements :class:`mmif.serialize.model.DataList`
     for :class:`mmif.serialize.document.Document`.
     """
     _items: Dict[str, Document]
 
-    def _deserialize(self, input_list: list) -> None:
+    def _deserialize(self, input_list: list) -> None:  # pytype: disable=signature-mismatch
         """
         Extends base ``_deserialize`` method to initialize ``items`` as a dict from
         document IDs to :class:`mmif.serialize.document.Document` objects.
@@ -457,7 +423,7 @@ class ViewsList(DataList[View]):
     """
     _items: Dict[str, View]
 
-    def _deserialize(self, input_list: list) -> None:
+    def _deserialize(self, input_list: list) -> None:  # pytype: disable=signature-mismatch
         """
         Extends base ``_deserialize`` method to initialize ``items`` as a dict from
         view IDs to :class:`mmif.serialize.view.View` objects.
